"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const semver_1 = require("semver");
const validator_1 = require("validator");
const errors_1 = require("./errors");
const IPV4_NUMBER = 4;
const IPV6_NUMBER = 6;
exports.validatePeerAddress = (ip, wsPort) => {
    if ((!validator_1.isIP(ip, IPV4_NUMBER) && !validator_1.isIP(ip, IPV6_NUMBER)) ||
        !validator_1.isPort(wsPort.toString())) {
        return false;
    }
    return true;
};
exports.validatePeerInfo = (rawPeerInfo) => {
    if (!rawPeerInfo) {
        throw new errors_1.InvalidPeerError(`Invalid peer object`);
    }
    const protocolPeer = rawPeerInfo;
    if (!protocolPeer.ip ||
        !protocolPeer.wsPort ||
        !exports.validatePeerAddress(protocolPeer.ip, protocolPeer.wsPort)) {
        throw new errors_1.InvalidPeerError(`Invalid peer ip or port`);
    }
    if (!protocolPeer.version || !semver_1.valid(protocolPeer.version)) {
        throw new errors_1.InvalidPeerError(`Invalid peer version`);
    }
    const version = protocolPeer.version;
    const wsPort = +protocolPeer.wsPort;
    const os = protocolPeer.os ? protocolPeer.os : '';
    const height = protocolPeer.height && validator_1.isNumeric(protocolPeer.height.toString())
        ? +protocolPeer.height
        : 0;
    const peerInfo = {
        ipAddress: protocolPeer.ip,
        wsPort,
        height,
        os,
        version,
        options: Object.assign({ httpPort: protocolPeer.httpPort, broadhash: protocolPeer.broadhash, nonce: protocolPeer.nonce }, protocolPeer.options),
        isDiscoveredPeer: true,
    };
    return peerInfo;
};
exports.validatePeerInfoList = (rawPeerInfoList) => {
    if (!rawPeerInfoList) {
        throw new errors_1.InvalidRPCResponseError('Invalid response type');
    }
    const { peers } = rawPeerInfoList;
    if (Array.isArray(peers)) {
        const peerList = peers.map(exports.validatePeerInfo);
        return peerList;
    }
    else {
        throw new errors_1.InvalidRPCResponseError('Invalid response type');
    }
};
exports.validateRPCRequest = (request) => {
    if (!request) {
        throw new errors_1.InvalidRPCRequestError('Invalid request');
    }
    const rpcRequest = request;
    if (typeof rpcRequest.procedure !== 'string') {
        throw new errors_1.InvalidRPCRequestError('Request procedure name is not a string');
    }
    return rpcRequest;
};
exports.validateProtocolMessage = (message) => {
    if (!message) {
        throw new errors_1.InvalidProtocolMessageError('Invalid message');
    }
    const protocolMessage = message;
    if (typeof protocolMessage.event !== 'string') {
        throw new errors_1.InvalidProtocolMessageError('Protocol message is not a string');
    }
    return protocolMessage;
};
//# sourceMappingURL=validation.js.map